v1.0.5.post1
=============
- :func:`rohub.resource_update_metadata` allows moving back the resource to the home folder by passing "/" as a value for the folder argument
- added functions: 
    * :func:`rohub.ros_completeness`
    * :func:`ResearchObject.completeness`
    * :func:`rohub.ros_enrich`
    * :func:`ResearchObject.enrich`
- extended list of ResearchObject's attributes that are accessible after loading full resource_update_metadata
    * publishers
    * copyrights
    * number_of_references
    * completeness
    * completeness_calculate_on
    * completeness_check_report
    * cite_as
    * license
    * funding
    * communities
    * main_entity